import { MenuItem, RoleNameType, roleMenusMapping } from "./roleMenu.config";
import { UserService } from "@@/domain/User/UserService";
import { useEffect, useState } from "react";
import { observer } from "mobx-react-lite";
import { useNavigate } from "react-router";
import { Menu, Spin } from "antd";

export const useMenu = () => {
  const navigate = useNavigate();
  const [selectedKeys, setSelectedKeys] = useState([location.pathname]);

  useEffect(() => setSelectedKeys([location.pathname]), []);

  const RoleMenu: React.FC<{ domainService: UserService }> = observer(
    ({ domainService }) => {
      const { user } = domainService;
      console.log(user);
      const roleNames = user.getRolesName();
      if (roleNames) {
        let menuItems: MenuItem[] = [];
        for (const key in roleMenusMapping)
          if (roleNames.includes(key))
            menuItems = roleMenusMapping[key as RoleNameType];
        return (
          <Menu
            onClick={(e) => navigate(e.key)}
            style={{ width: "100%", height: "100%" }}
            selectedKeys={selectedKeys}
            defaultOpenKeys={["dicom"]}
            mode="inline"
            items={menuItems}
          />
        );
      } else {
        return (
          <div style={{ textAlign: "center" }}>
            <Spin />
          </div>
        );
      }
    }
  );

  return { RoleMenu };
};
